### Name: fpca
### Title: Focused Principal Components Analysis
### Aliases: fpca
### Keywords: multivariate

### ** Examples

data(sleep)
fpca(sleep,5,c(2:4,7:11)) 
## focused PCA of the duration of paradoxical sleep (dreams, 5th column)
## against constitutional variables in mammals (columns 2, 3, 4, 7, 8, 9, 10, 11).
## Variables inside the red cercle are significantly correlated
## to the dependent variable with p<0.05.
## Green variables are positively correlated to the dependent variable,
## yellow variables are negatively correlated.
## There are three clear clusters of independent variables.
corsleep <- as.data.frame(cor(sleep[,2:11],use="pairwise.complete.obs"))
fpca(corsleep,4,c(1:3,6:10),input="Cor",sample.size=60) 
## when missing data are numerous, the representation of a pairwise correlation
## matrix may be preferred (even if mathematical properties are not so good...)
numer <- c(2:4,7:11)
l <- length(numer)
resu <- matrix(ncol=2,nrow=l)
resu <- as.data.frame(resu)
for(i in 1:l)
{
int <- sleep[,numer[i]]
mod <- lm(sleep$Paradoxical.sleep~int)
resu[i,2] <-  summary(mod)[[4]][2,4]*sign(summary(mod)[[4]][2,1])
}
resu[,1] <- dimnames(sleep[,c(2:4,7:11)])[2][[1]]
fpca(sleep,5,c(2:4,7:11),pvalues=resu[,2])
## A representation with p values
## When input="Cor" or pvalues"Yes" partial is turned to "No"



